@@ -1,6 +1,6 @@
 import logging
 from http import HTTPStatus
-from .errors import ERROR_MSG
+from . import consts
 
 
 class APIError(Exception):
@@ -14,7 +14,7 @@ class APIError(Exception):
                  status_code=None,
                  logging_level=None):
         cls = self.__class__
-        self.user_hint = user_hint or ERROR_MSG.get(status_code, f'')
+        self.user_hint = user_hint or consts.ERROR_MSG.get(status_code, '')
         self.logging_hint = logging_hint or self.user_hint
         self.status_code = status_code or cls.status_code
         self.logging_level = logging_level or cls.logging_level
@@ -33,13 +33,17 @@ class InternalError(APIError):
     logging_level = logging.ERROR
 
 
+class InvalidRequestBody(APIError):
+    status_code = HTTPStatus.BAD_REQUEST
+
+
 class ParamsError(APIError):
     status_code = HTTPStatus.BAD_REQUEST
     logging_level = logging.WARNING
 
 
 class ValidationError(ParamsError):
-    messages = ERROR_MSG.get(HTTPStatus.UNPROCESSABLE_ENTITY)
+    messages = consts.ERROR_MSG.get(HTTPStatus.BAD_REQUEST)
 
 
 class Unauthorized(APIError):
