@@ -1,6 +1,6 @@
-from simple_django_api.utils import SettingsProxy
+from simple_django_api.utils.settings import FallbackSettings
 
-settings = SettingsProxy(
+settings = FallbackSettings(
     API_JWT_ALGORITHM='HS256',
     API_JWT_AUTH_COOKIE='',
     API_JWT_VERIFY_EXPIRATION=True,
